xprofile
========

A tool to manage and automatically apply xrandr configurations.


installation
------------

A universal installation method is to use pip::

    $ pip install --upgrade xprofile


usage
-----

Once `xprofile` has been installed you can execute the following command to get
some help::

    $ xprofile --help
